<?php
/**
 * Genie base inclusion file.
 *
 * $Horde: genie/lib/base.php,v 1.24 2004/10/19 00:45:31 chuck Exp $
 *
 * This file brings in all of the dependencies that every Genie
 * script will need and sets up objects that all scripts use.
 */

// Check for a prior definition of HORDE_BASE (perhaps by an
// auto_prepend_file definition for site customization).
if (!defined('HORDE_BASE')) {
    @define('HORDE_BASE', dirname(__FILE__) . '/../..');
}

// Load the Horde Framework core, and set up inclusion paths.
require_once HORDE_BASE . '/lib/core.php';

// Registry.
$registry = &Registry::singleton();
if (is_a(($pushed = $registry->pushApp('genie', !defined('AUTH_HANDLER'))), 'PEAR_Error')) {
    if ($pushed->getCode() == 'permission_denied') {
        Horde::authenticationFailureRedirect(); 
    }
    Horde::fatal($pushed, __FILE__, __LINE__, false);
}
$conf = &$GLOBALS['conf'];
@define('GENIE_TEMPLATES', $registry->get('templates'));

// Notification system.
$notification = &Notification::singleton();
$notification->attach('status');

// Find the base file path of Genie.
@define('GENIE_BASE', dirname(__FILE__) . '/..');

// Genie base libraries
require_once GENIE_BASE . '/lib/Genie.php';
require_once GENIE_BASE . '/lib/Driver.php';

// Horde libraries.
require_once 'Horde/Text/Filter.php';
require_once 'Horde/Help.php';

// Set the timezone variable, if available.
NLS::setTimeZone();

// Make sure a session exists
if (!array_key_exists('genie', $_SESSION)) {
    $_SESSION['genie'] = array();
}

// Create a share instance.
require_once 'Horde/Share.php';
$GLOBALS['genie_shares'] = &Horde_Share::singleton($registry->getApp());

// Update the preference for what wishlists to display. If the user doesn't
// have any selected wishlists for view then fall back to some available
// list.
$GLOBALS['display_wishlists'] = unserialize($GLOBALS['prefs']->getValue('display_wishlists'));
if (($d_wish = Util::getFormData('display_wishlist')) !== null) {
    if (in_array($d_wish, $GLOBALS['display_wishlists'])) {
        $key = array_search($d_wish, $GLOBALS['display_wishlists']);
        unset($GLOBALS['display_wishlists'][$key]);
    } else {
        $GLOBALS['display_wishlists'][] = $d_wish;
    }
}

// Make sure all wishlists exist now, to save on checking later.
$_temp = $GLOBALS['display_wishlists'];
$_all = Genie::listWishlists();
$GLOBALS['display_wishlists'] = array();
foreach ($_temp as $id) {
    if (isset($_all[$id])) {
        $GLOBALS['display_wishlists'][] = $id;
    }
}

if (count($GLOBALS['display_wishlists']) == 0) {
    $lists = Genie::listWishlists(true);
    if (!Auth::getAuth()) {
        // All wishlists for guests.
        $GLOBALS['display_wishlists'] = array_keys($lists);
    } elseif (!count($lists)) {
        // Create a personal wishlist.
        $GLOBALS['display_wishlists'] = array(Auth::getAuth());

        // If this share doesn't exist then create it.
        if (!$GLOBALS['genie_shares']->exists(Auth::getAuth())) {
            require_once 'Horde/Identity.php';
            $identity = &Identity::singleton();
            $name = $identity->getValue('fullname');
            if (trim($name) == '') {
                $name = Auth::removeHook(Auth::getAuth());
            }
            $share = $GLOBALS['genie_shares']->newShare(Auth::getAuth());
            $share->set('name', sprintf(_("%s's Wishlist"), $name));
            $GLOBALS['genie_shares']->addShare($share);
        }
    }
}

$GLOBALS['prefs']->setValue('display_wishlists', serialize($GLOBALS['display_wishlists']));
